===============
Mia! Accounting
===============


Description
===========

This is the Mia! Accounting project.  It is an accounting
module for the Flask_ applications.


Install
=======

Install ``mia-accounting`` with ``pip``.

::

    pip install mia-accounting


Usage
=====

This needs to be done.  Currently, you can refer to the test site
located in the test directory on the `Mia! Accounting repository`_.

The test site is running as the
`live demonstration for Mia! Accounting`_.


Copyright
=========

 Copyright (c) 2023 imacat.

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.


Authors
=======

| imacat
| imacat@mail.imacat.idv.tw
| 2023/1/27

.. _Flask: https://flask.palletsprojects.com
.. _Mia! Accounting repository: https://github.com/imacat/mia-accounting
.. _live demonstration for Mia! Accounting: https://accounting.imacat.idv.tw
